# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: versions_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15versions_common.proto\x12\x1c\x61rmonik.api.grpc.v1.versions\"\x15\n\x13ListVersionsRequest\"1\n\x14ListVersionsResponse\x12\x0c\n\x04\x63ore\x18\x01 \x01(\t\x12\x0b\n\x03\x61pi\x18\x02 \x01(\tB\x1f\xaa\x02\x1c\x41rmoniK.Api.gRPC.V1.Versionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'versions_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\034ArmoniK.Api.gRPC.V1.Versions'
  _globals['_LISTVERSIONSREQUEST']._serialized_start=55
  _globals['_LISTVERSIONSREQUEST']._serialized_end=76
  _globals['_LISTVERSIONSRESPONSE']._serialized_start=78
  _globals['_LISTVERSIONSRESPONSE']._serialized_end=127
# @@protoc_insertion_point(module_scope)
