# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: submitter_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import objects_pb2 as objects__pb2
from ..common import submitter_common_pb2 as submitter__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17submitter_service.proto\x12\x1d\x61rmonik.api.grpc.v1.submitter\x1a\robjects.proto\x1a\x16submitter_common.proto2\xe0\r\n\tSubmitter\x12^\n\x17GetServiceConfiguration\x12\x1a.armonik.api.grpc.v1.Empty\x1a\".armonik.api.grpc.v1.Configuration\"\x03\x88\x02\x01\x12|\n\rCreateSession\x12\x33.armonik.api.grpc.v1.submitter.CreateSessionRequest\x1a\x31.armonik.api.grpc.v1.submitter.CreateSessionReply\"\x03\x88\x02\x01\x12N\n\rCancelSession\x12\x1c.armonik.api.grpc.v1.Session\x1a\x1a.armonik.api.grpc.v1.Empty\"\x03\x88\x02\x01\x12~\n\x10\x43reateSmallTasks\x12\x35.armonik.api.grpc.v1.submitter.CreateSmallTaskRequest\x1a..armonik.api.grpc.v1.submitter.CreateTaskReply\"\x03\x88\x02\x01\x12\x80\x01\n\x10\x43reateLargeTasks\x12\x35.armonik.api.grpc.v1.submitter.CreateLargeTaskRequest\x1a..armonik.api.grpc.v1.submitter.CreateTaskReply\"\x03\x88\x02\x01(\x01\x12\\\n\tListTasks\x12).armonik.api.grpc.v1.submitter.TaskFilter\x1a\x1f.armonik.api.grpc.v1.TaskIdList\"\x03\x88\x02\x01\x12o\n\x0cListSessions\x12,.armonik.api.grpc.v1.submitter.SessionFilter\x1a,.armonik.api.grpc.v1.submitter.SessionIdList\"\x03\x88\x02\x01\x12X\n\nCountTasks\x12).armonik.api.grpc.v1.submitter.TaskFilter\x1a\x1a.armonik.api.grpc.v1.Count\"\x03\x88\x02\x01\x12k\n\x12TryGetResultStream\x12\".armonik.api.grpc.v1.ResultRequest\x1a*.armonik.api.grpc.v1.submitter.ResultReply\"\x03\x88\x02\x01\x30\x01\x12\\\n\x10TryGetTaskOutput\x12&.armonik.api.grpc.v1.TaskOutputRequest\x1a\x1b.armonik.api.grpc.v1.Output\"\x03\x88\x02\x01\x12p\n\x13WaitForAvailability\x12\".armonik.api.grpc.v1.ResultRequest\x1a\x30.armonik.api.grpc.v1.submitter.AvailabilityReply\"\x03\x88\x02\x01\x12`\n\x11WaitForCompletion\x12*.armonik.api.grpc.v1.submitter.WaitRequest\x1a\x1a.armonik.api.grpc.v1.Count\"\x03\x88\x02\x01\x12Y\n\x0b\x43\x61ncelTasks\x12).armonik.api.grpc.v1.submitter.TaskFilter\x1a\x1a.armonik.api.grpc.v1.Empty\"\x03\x88\x02\x01\x12|\n\rGetTaskStatus\x12\x33.armonik.api.grpc.v1.submitter.GetTaskStatusRequest\x1a\x31.armonik.api.grpc.v1.submitter.GetTaskStatusReply\"\x03\x88\x02\x01\x12\x82\x01\n\x0fGetResultStatus\x12\x35.armonik.api.grpc.v1.submitter.GetResultStatusRequest\x1a\x33.armonik.api.grpc.v1.submitter.GetResultStatusReply\"\x03\x88\x02\x01\x12|\n\x0cWatchResults\x12\x31.armonik.api.grpc.v1.submitter.WatchResultRequest\x1a\x30.armonik.api.grpc.v1.submitter.WatchResultStream\"\x03\x88\x02\x01(\x01\x30\x01\x42 \xaa\x02\x1d\x41rmoniK.Api.gRPC.V1.Submitterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'submitter_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\035ArmoniK.Api.gRPC.V1.Submitter'
  _SUBMITTER.methods_by_name['GetServiceConfiguration']._options = None
  _SUBMITTER.methods_by_name['GetServiceConfiguration']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['CreateSession']._options = None
  _SUBMITTER.methods_by_name['CreateSession']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['CancelSession']._options = None
  _SUBMITTER.methods_by_name['CancelSession']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['CreateSmallTasks']._options = None
  _SUBMITTER.methods_by_name['CreateSmallTasks']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['CreateLargeTasks']._options = None
  _SUBMITTER.methods_by_name['CreateLargeTasks']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['ListTasks']._options = None
  _SUBMITTER.methods_by_name['ListTasks']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['ListSessions']._options = None
  _SUBMITTER.methods_by_name['ListSessions']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['CountTasks']._options = None
  _SUBMITTER.methods_by_name['CountTasks']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['TryGetResultStream']._options = None
  _SUBMITTER.methods_by_name['TryGetResultStream']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['TryGetTaskOutput']._options = None
  _SUBMITTER.methods_by_name['TryGetTaskOutput']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['WaitForAvailability']._options = None
  _SUBMITTER.methods_by_name['WaitForAvailability']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['WaitForCompletion']._options = None
  _SUBMITTER.methods_by_name['WaitForCompletion']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['CancelTasks']._options = None
  _SUBMITTER.methods_by_name['CancelTasks']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['GetTaskStatus']._options = None
  _SUBMITTER.methods_by_name['GetTaskStatus']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['GetResultStatus']._options = None
  _SUBMITTER.methods_by_name['GetResultStatus']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['WatchResults']._options = None
  _SUBMITTER.methods_by_name['WatchResults']._serialized_options = b'\210\002\001'
  _globals['_SUBMITTER']._serialized_start=98
  _globals['_SUBMITTER']._serialized_end=1858
# @@protoc_insertion_point(module_scope)
